@@ -83,6 +83,21 @@ KSample::KSample(KTimeMon *t, bool a, unsigned p, unsigned s, unsigned c) :
   pageScale(p), swapScale(s), cxScale(c), autoscale(a)
 {
 #ifdef __linux__
+  memstats[0].name = "SwapTotal:";
+  memstats[0].stat = &sample.stotal;
+  memstats[1].name = "MemTotal:";
+  memstats[1].stat = &sample.mtotal;
+  memstats[2].name = "MemFree:";
+  memstats[2].stat = &sample.free;
+  memstats[3].name = "Buffers:";
+  memstats[3].stat = &sample.buffers;
+  memstats[4].name = "Cached:";
+  memstats[4].stat = &sample.cached;
+  memstats[5].name = "SwapFree:";
+  memstats[5].stat = &sample.sfree;
+  memstats[6].name = 0;
+  memstats[6].stat = 0;
+
 
   parseMtab(proc);
 
@@ -223,7 +238,7 @@ void KSample::fatal(const QString& msg)
     timemon->stop();
 
     KMessageBox::error(timemon, msg);
-    exit(1);
+//    exit(1);
 }
 
 
@@ -264,23 +279,11 @@ void KSample::readSample()
 
     lseek(memFD, 0, 0);
     if ((l = read(memFD, buffer, sizeof(buffer) - 1)) < 0)
+    {
         fatal(i18n("Unable to read the memory usage file '%1/%2'.\n"
                    "The diagnostics are: %3").arg(proc).arg(MEMINFO_NAME).arg(strerror(errno)));
-
+    }
     buffer[l] = '\0';
-    static struct {
-        const char *name;
-        unsigned long *stat;
-    } memstats[] = {
-        { "SwapTotal:", &sample.stotal },
-        { "MemTotal:", &sample.mtotal },
-        { "MemFree:", &sample.free },
-        { "Buffers:", &sample.buffers },
-        { "Cached:", &sample.cached },
-        { "SwapFree:", &sample.sfree },
-        { 0, 0 }
-    };
-
     l = 0;
     char *p;
     while (memstats[l].name != 0) {
