@@ -49,6 +49,11 @@ public:
         void fill(unsigned scale);	// fill sample with some fake values
     };
 
+    struct MemStats {
+        const char *name;
+        unsigned long *stat;
+    };
+
     KSample(KTimeMon *timemon, bool autoScale, unsigned pageScale,
             unsigned swapScale, unsigned ctxScale);
     virtual ~KSample();
@@ -85,6 +90,7 @@ private:
     Sample sample, oldSample;
     unsigned pageScale, swapScale, cxScale;
     bool autoscale;
+    struct MemStats memstats[7];
 };
 
 #endif // SAMPLE_H
