@@ -108,6 +108,12 @@ void KTimeMon::paintEvent(QPaintEvent *)
 
     b = r / 3;            // bar width
     r -= b;
+
+    if (bgColour != colorGroup().background())
+    {
+        paintRect(x, 0, b, h, bgColour, &painter);
+    }
+
     y = h - s.kernel; paintRect(x, y, b, s.kernel, kernelColour, &painter);
     y -= s.user; paintRect(x, y, b, s.user, userColour, &painter);
     y -= s.nice; paintRect(x, y, b, s.nice, niceColour, &painter);
@@ -115,12 +121,24 @@ void KTimeMon::paintEvent(QPaintEvent *)
     x += b;
     b = r / 2;
     r -= b;
+
+    if (bgColour != colorGroup().background())
+    {
+        paintRect(x, 0, b, h, bgColour, &painter);
+    }
+
     y = h - s.used; paintRect(x, y, b, s.used, usedColour, &painter);
     y -= s.buffers; paintRect(x, y, b, s.buffers, buffersColour, &painter);
     y -= s.cached; paintRect(x, y, b, s.cached, cachedColour, &painter);
 
     x += b;
     b = r;
+
+    if (bgColour != colorGroup().background())
+    {
+        paintRect(x, 0, b, h, bgColour, &painter);
+    }
+
     y = h - s.sused; paintRect(x, y, b, s.sused, swapColour, &painter);
     painter.end();
 
