@@ -14,8 +14,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include "arkplugin.h"
@@ -31,6 +31,7 @@
 #include <kpopupmenu.h>
 #include <kgenericfactory.h>
 #include <kurl.h>
+#include <kio/netaccess.h>
 
 #include <qdir.h>
 #include <qcstring.h>
@@ -58,6 +59,7 @@ ArkMenu::ArkMenu( KonqPopupMenu * popupmenu, const char *name, const QStringList
 
     extMimeTypes();
     m_list = popupmenu->fileItemList();
+    m_dir = popupmenu->url().url() + "/";
     unsigned int itemCount = m_list.count();
     KFileItemListIterator it( m_list );
     KFileItem * item;
@@ -383,13 +385,25 @@ void ArkMenu::slotCompressAs( int pos )
     KURL target;
     KFileItemListIterator it( m_list );
     KFileItem * item;
+    QStringList filelist;
     while (  ( item = it.current() ) != 0 )
     {
-        ++it;
-        target = item->url();
-        target.setPath( target.path( -1 ) + m_extensionList[ pos ] );
-        compressAs( item->url(), target );
+         ++it;
+         filelist.append( item->url().url() );
     }
+    if ( filelist.count() == 1)
+         target = filelist.first() + m_extensionList[ pos ];
+    else
+    {
+        target = m_dir + i18n("Archive") + m_extensionList[ pos ];
+        int i=1;
+        while ( KIO::NetAccess::exists(target, true, 0 ) )
+        {
+            target = m_dir + i18n("Archive %1").arg(i) + m_extensionList[ pos ];
+            i++;
+        }
+    }
+    compressAs( filelist, target );
 
     extension = m_extensionList[ pos ];
     m_conf->setGroup( "ArkPlugin" );
@@ -422,20 +436,34 @@ void ArkMenu::slotCompressAsDefault()
     KFileItemListIterator it( m_list );
     KFileItem * item;
     KURL name;
+    QStringList filelist;
     while (  ( item = it.current() ) != 0 )
     {
-        ++it;
-        name = item->url();
-        name.setPath( name.path( -1 ) + m_ext );
-        compressAs( item->url(), name );
+         ++it;
+         filelist.append( item->url().url() );
     }
+    if ( filelist.count() == 1)
+         name = filelist.first() + m_ext;
+    else
+    {
+        name = m_dir + i18n("Archive") + m_ext;
+        int i=1;
+        while ( KIO::NetAccess::exists(name, true, 0 ) )
+        {
+            name = m_dir + i18n("Archive %1").arg(i) + m_ext;
+            i++;
+        }
+    }
+    compressAs( filelist, name );
 }
 
 // make work for URLs
-void ArkMenu::compressAs( const KURL & name, const KURL & compressed )
+void ArkMenu::compressAs( const QStringList &name, const KURL & compressed )
 {
     QStringList args;
-    args << "--add-to" << name.url() << compressed.url();
+    args << "--add-to";
+    args += name;
+    args << compressed.url();
     kapp->kdeinitExec( "ark", args );
 }
 
