@@ -2,6 +2,7 @@
  *   Copyright (C) 2002, Anders Lund <anders@alweb.dk>                     *
  *   Copyright (C) 2003, 2004, Franck Qulain <shift@free.fr>              *
  *   Copyright (C) 2004, Kevin Krammer <kevin.krammer@gmx.at>              *
+ *   Copyright (C) 2004, 2005, Oliviet Goffart <ogoffart @ kde.org>        *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,7 +17,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
  ***************************************************************************/
 
 
@@ -248,6 +249,7 @@ void RelLinksPlugin::loadingFinished() {
     m_pollTimer->stop();
     //kdDebug(90210) << "loadingFinished()" << endl;
     updateToolbar();
+	guessRelations();
 }
 
 /* Update the site navigation bar */
@@ -291,7 +293,8 @@ void RelLinksPlugin::updateToolbar() {
         // Determin the name used internally
         QString lrel = getLinkType(rel.lower());
         // relation to ignore
-        if (lrel == NULL) continue;
+        if (lrel.isEmpty()) continue;
+	kdDebug() << "lrel=" << lrel << endl;
 
         // -- Retrieve of other usefull informations --
 
@@ -359,6 +362,62 @@ void RelLinksPlugin::updateToolbar() {
 }
 
 
+void RelLinksPlugin::guessRelations()
+{
+	KHTMLPart *part = dynamic_cast<KHTMLPart *>(parent());
+	if (!part)
+		return;
+	
+	//If the page already contains some link, that mean the webmaster is aware
+	//of the meaning of <link> so we can consider that if prev/next was possible
+	//they are already there.
+	if(!element_map.isEmpty())
+		return;
+
+	// - The number of didgit may not be more of 3, or this is certenly an id.
+	// - We make sure that the number is followed by a dot, a &, or the end, we
+	//   don't want to match stuff like that:   page.html?id=A14E12FD
+	// - We make also sure the number is not preceded dirrectly by others number
+	QRegExp rx("^(.*[=/?&][^=/?&.\\-0-9]*)([\\d]{1,3})([.&][^/0-9]{0,15})?$");
+	
+	
+	const QString zeros("0000");
+	QString url=part->url().url();
+	if(rx.search(url)!=-1)
+	{
+		uint val=rx.cap(2).toUInt();
+		uint lenval=rx.cap(2).length();
+		QString nval_str=QString::number(val+1);
+		//prepend by zeros if the original also contains zeros.
+		if(nval_str.length() < lenval && rx.cap(2)[0]=='0')
+			nval_str.prepend(zeros.left(lenval-nval_str.length()));
+
+		QString href=rx.cap(1)+ nval_str + rx.cap(3);
+		KURL ref( m_part->url(), href );
+		QString title = i18n("[Autodetected] %1").arg(ref.prettyURL());
+		DOM::Element e= m_part->document().createElement("link");
+		e.setAttribute("href",href);
+		element_map["next"][0] = e;
+		kaction_map["next"]->setEnabled(true);
+		kaction_map["next"]->setToolTip( title );
+
+		if(val>1)
+		{
+			nval_str=QString::number(val-1);
+			if(nval_str.length() < lenval && rx.cap(2)[0]=='0')
+				nval_str.prepend(zeros.left(lenval-nval_str.length()));
+			QString href=rx.cap(1)+ nval_str + rx.cap(3);
+			KURL ref( m_part->url(), href );
+			QString title = i18n("[Autodetected] %1").arg(ref.prettyURL());
+			e= m_part->document().createElement("link");
+			e.setAttribute("href",href);
+			element_map["prev"][0] = e;
+			kaction_map["prev"]->setEnabled(true);
+			kaction_map["prev"]->setToolTip( title );
+		}
+	}
+}
+
 
 /** Menu links */
 void RelLinksPlugin::goToLink(const QString & rel, int id) {
@@ -502,13 +561,12 @@ void RelLinksPlugin::disableAll() {
 
 QString RelLinksPlugin::getLinkType(const QString &lrel) {
     // Relations to ignore...
-    if (lrel == "stylesheet"
-          || lrel == "alternate stylesheet"
+    if (lrel.contains("stylesheet")
           || lrel == "script"
           || lrel == "icon"
           || lrel == "shortcut icon"
           || lrel == "prefetch" )
-        return NULL;
+        return QString::null;
 
     // ...known relations...
     if (lrel == "top" || lrel == "origin" || lrel == "start")
@@ -554,7 +612,7 @@ QString RelLinksPlugin::transformRevToRel(const QString &rev) {
         return getLinkType("sibling");
 
     //...unknown inverse relation => ignore for the moment
-    return NULL;
+    return QString::null;
 }
 
 #include "plugin_rellinks.moc"
