@@ -24,6 +24,7 @@
 #include <kstandarddirs.h>
 #include <kmessagebox.h>
 #include <kglobal.h>
+#include <kdemacros.h>
 #include "mediawidget.h"
 
 KonqSidebar_MediaPlayer::KonqSidebar_MediaPlayer(KInstance *instance,QObject *parent,QWidget *widgetParent, QString &desktopName_, const char* name):
@@ -50,7 +51,7 @@ void KonqSidebar_MediaPlayer::handleURL(const KURL &/*url*/)
 
 extern "C"
 {
-    void* create_konqsidebar_mediaplayer(KInstance *instance,QObject *par,QWidget *widp,QString &desktopname,const char *name)
+    KDE_EXPORT void* create_konqsidebar_mediaplayer(KInstance *instance,QObject *par,QWidget *widp,QString &desktopname,const char *name)
     {
 	KGlobal::locale()->insertCatalogue("konqsidebar_mediaplayer");
         return new KonqSidebar_MediaPlayer(instance,par,widp,desktopname,name);
@@ -59,7 +60,7 @@ extern "C"
 
 extern "C"
 {
-   bool add_konqsidebar_mediaplayer(QString* fn, QString* /*param*/, QMap<QString,QString> *map)
+   KDE_EXPORT bool add_konqsidebar_mediaplayer(QString* fn, QString* /*param*/, QMap<QString,QString> *map)
    {
 		        map->insert("Type","Link");
 			map->insert("Icon","konqsidebar_mediaplayer");
