@@ -13,11 +13,11 @@
  *
  *  You should have received a copy of the GNU Library General Public License
  *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- *  Boston, MA 02111-1307, USA.
+ *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ *  Boston, MA 02110-1301, USA.
  **/
 
-/* $Id: plugin_webarchiver.cpp 424045 2005-06-10 15:31:07Z pletourn $ */
+/* $Id: plugin_webarchiver.cpp 465369 2005-09-29 14:33:08Z mueller $ */
 
 /*
  * There are two recursions within this code:
@@ -102,7 +102,7 @@ void PluginWebArchiver::slotSaveToArchive()
   if (file.exists()) {
     const QString title = i18n( "File Exists" );
     const QString text = i18n( "Do you really want to overwrite:\n%1?" ).arg(url.prettyURL());
-    if (KMessageBox::Yes != KMessageBox::warningYesNoCancel( part->widget(), text, title ) ) {
+    if (KMessageBox::Continue != KMessageBox::warningContinueCancel( part->widget(), text, title, i18n("Overwrite") ) ) {
       return;
     }
   }
