@@ -107,7 +107,7 @@ void Bitmap::drawCircle(int x, int y, int r, Pixel color)
 	int16_t d_se = -2 * r + 5;
 	int16_t xpcx, xmcx, xpcy, xmcy;
 	int16_t ypcy, ymcy, ypcx, ymcx;
- 
+
 	do
 	{ // Draw
 		if ((ocy!=cy) || (ocx!=cx))
@@ -128,7 +128,7 @@ void Bitmap::drawCircle(int x, int y, int r, Pixel color)
 				setPixel(xmcx,y,color);
 				setPixel(xpcx,y,color);
 			}
-			
+
 			ocy=cy;
 			xpcy=x+cy;
 			xmcy=x-cy;
@@ -178,7 +178,7 @@ void Bitmap::fillCircle(int x, int y, int r, Pixel color)
 	int16_t d_se = -2 * r + 5;
 	int16_t xpcx, xmcx, xpcy, xmcy;
 	int16_t ypcy, ymcy, ypcx, ymcx;
- 
+
 	do
 	{ // Draw
 		if ((ocy!=cy) || (ocx!=cx))
@@ -195,7 +195,7 @@ void Bitmap::fillCircle(int x, int y, int r, Pixel color)
 				setPixel(xpcx,ymcy,color);
 				for (int h=xmcx; h<xpcx; h++)
 					setPixel(h, ypcy, color);
-				
+
 				for (int h=xmcx; h<xpcx; h++)
 					setPixel(h, ymcy, color);
 			}
@@ -206,8 +206,8 @@ void Bitmap::fillCircle(int x, int y, int r, Pixel color)
 				for (int h=xmcx; h<xpcx; h++)
 					setPixel(h, y, color);
 			}
-			
-			
+
+
 			ocy=cy;
 			xpcy=x+cy;
 			xmcy=x-cy;
@@ -221,7 +221,7 @@ void Bitmap::fillCircle(int x, int y, int r, Pixel color)
 				setPixel(xpcy,ymcx,color);
 				for (int h=xmcy; h<xpcy; h++)
 					setPixel(h, ypcx, color);
-				
+
 				for (int h=xmcy; h<xpcy; h++)
 					setPixel(h, ymcx, color);
 			}
@@ -259,18 +259,18 @@ void Bitmap::drawLine(int x1, int y1, int x2, int y2, Pixel color)
 	int dx = x2 - x1;
 	int sx = (dx >= 0) ? 1 : -1;
 	dx = sx * dx + 1;
-	
+
 	int dy = y2 - y1;
 	int sy = (dy >= 0) ? 1 : -1;
 	dy = sy * dy + 1;
-	
+
 
 	int pixx = sizeof(Pixel);
 	int pixy = width*sizeof(Pixel);
 	uint8_t *pixel = (uint8_t*)pixels() + pixx * x1 + pixy * y1;
 	pixx *= sx;
 	pixy *= sy;
-	
+
 	if (dx < dy)
 	{
 		int swaptmp = dx;
@@ -281,17 +281,17 @@ void Bitmap::drawLine(int x1, int y1, int x2, int y2, Pixel color)
 		pixy = swaptmp;
 	}
 
-	
+
 	// Draw
 	int y=0;
-	
+
 	for(int x=0; x < dx; x++, pixel += pixx)
 	{
 		*(Pixel*)pixel=color;
 		y += dy;
 		if (y >= dx)
 		{
-			y -= dx; 
+			y -= dx;
 			pixel += pixy;
 		}
 	}
@@ -311,27 +311,27 @@ RendererList::~RendererList()
 Bitmap *RendererList::render(float *pcm[4], Bitmap *source)
 {
 	if (mClearAfter) mFrame->clear();
-	
+
 	lock();
 	for (QPtrListIterator<Renderer> i(mRendererList); i.current(); ++i)
 	{
 		Bitmap *newframe=(*i)->render(pcm, mFrame);
-	
+
 		if (newframe!=mFrame)
 		{
 			nex->bitmapPool()->release(mFrame);
 			mFrame=newframe;
 		}
 	}
-	
+
 	unlock();
-	
+
 	// add source+=source; return source;
-	
+
 	uint8_t *d=(uint8_t*)source->pixels();
 	uint8_t *end=(uint8_t*)((uint8_t*)d+source->bytes());
 	uint8_t *s=(uint8_t*)mFrame->pixels();
-	
+
 	while (d<end)
 	{
 		register int dest=*d;
@@ -350,12 +350,12 @@ Bitmap *RendererList::render(float *pcm[4], Bitmap *source)
 			// can't possibly be more than 0xFF
 			*d=dest+*s;
 		}
-		
-		
+
+
 		++s;
 		++d;
 	}
-	
+
 	return source;
 }
 
@@ -363,35 +363,35 @@ void RendererList::save(QDomElement &e)
 {
 	lock();
 	e.setTagName("List");
-	
+
 	for (QPtrListIterator<Renderer> i(mRendererList); *i; ++i)
 	{
 		QDomElement item;
 		(*i)->save(item);
 		e.appendChild(item);
 	}
-	
+
 	unlock();
 }
 
 void RendererList::load(const QDomElement &e)
 {
 	lock();
-	
+
 	for (QDomNode n=e.firstChild(); !n.isNull(); n=n.nextSibling())
 	{
 		if (!n.isElement()) continue;
 		QDomElement child=n.toElement();
-		
+
 		Renderer *r=0;
-		
+
 		if (e.tagName()=="List")
 			r=new RendererList;
 		else
 			r=nex->renderer(e.tagName());
-		
+
 		if (!r) continue;
-			
+
 		r->load(child);
 		mRendererList.append(r);
 	}
@@ -420,9 +420,9 @@ RendererListConfigurator::RendererListConfigurator(RendererList *l, QWidget *par
 		connect(mConvolve, SIGNAL(toggled(bool)), SLOT(convolve(bool)));
 		mConvolve->setChecked(nex->input()->convolve());
 	}
-	
+
 	new QLabel(i18n("Comments"), this);
-	
+
 	mComments=new QMultiLineEdit(this);
 	mComments->setText(l->mComments);
 	mComments->setWordWrap(QMultiLineEdit::WidgetWidth);
@@ -452,7 +452,7 @@ Nex::Nex()
 	sNex=this;
 	mBitmapPool=0;
 	mRendererList=0;
-	
+
 	setupSize(width, height);
 
 	INSERT("Fade", Creators::fade);
@@ -483,31 +483,30 @@ void Nex::go()
 {
 	runLock.unlock();
 	float *audio[6];
-		
+
 	Bitmap *frame;
 	frame=mBitmapPool->get(true);
-	
+
 	int frames=0;
 	QTime start(QTime::currentTime());
-	
+
 	while (1)
 	{
 		mInput->getAudio(audio);
 		mRendererList->render(audio, frame);
 		int result=mOutput.display(frame);
-		
+
 		frames++;
-		
+
 		switch (result)
 		{
 		case OutputSDL::Exit:
-			cerr << "Trying" << endl;
+			std::cerr << "Trying" << std::endl;
 			delete mInput;
-			cerr << "Deleted" << endl;
+			std::cerr << "Deleted" << std::endl;
 
-			cout << "Frames per Second: "
-			     << frames/start.secsTo(QTime::currentTime()) << endl;
-			
+			std::cout << "Frames per Second: "
+			     << frames/start.secsTo(QTime::currentTime()) << std::endl;
 			return;
 		case OutputSDL::Resize:
 //			setupSize(width, height);
@@ -534,7 +533,7 @@ QStringList Nex::renderers() const
 {
 	QDictIterator<CreatorSig*> i(mCreators);
 	QStringList list;
-	
+
 	for (;i.current(); ++i)
 		list += i.currentKey();
 
@@ -559,27 +558,27 @@ int main(int argc, char **argv)
 {
 	Nex theNex;
 	Nex::sNex=&theNex;
-	
+
 #ifndef NOTHREAD
 	runLock.lock();
-	
+
 	VisThread vis;
 	vis.start();
-	
+
 	runLock.lock();
 #endif
-	
+
 	KAboutData aboutData("nex", I18N_NOOP("Nex"), "0.0.1",
 		I18N_NOOP("The awesome customizable scope"),
 		KAboutData::License_LGPL, "(C) 2001 Charles Samuels", 0,
 		"http://noatun.kde.org");
-	
+
 	aboutData.addAuthor("Charles Samuels", I18N_NOOP("Nex Author"),
 	                    "charles@kde.org");
-	
+
 	KCmdLineArgs::init( argc, argv, &aboutData );
 	KApplication app;
-	
+
 
 	(new Control)->show();
 #ifdef NOTHREAD
@@ -587,7 +586,7 @@ int main(int argc, char **argv)
 
 #else
 	app.exec();
-	
+
 	vis.wait();
 #endif
 	exit(0); //prevent segfault on exit, for some reason
